<?php

/**
	Heading Shortcode
**/

// Register Shortcode
if( ! function_exists( 'boc_shortcode_heading' ) ) {
	function boc_shortcode_heading( $atts, $content = null ) {

		$atts = vc_map_get_attributes('boc_heading', $atts );
		extract( $atts );

		// CSS Animation
		$css_animation_classes = "";
		if ( $css_animation !== '' ) {
			$css_animation_classes = 'boc_animate_when_almost_visible boc_'. $css_animation .'';
		}
		
		$custom_styles = array();
		
		if( $margin_bot!=='20px' ) {
			$custom_styles[] = 'margin-bottom: '. $margin_bot .';';
		}
		if (( $margin_top!='0px' ) && ($margin_top!='')) {
			$custom_styles[] = 'margin-top: '. $margin_top .';';
		}

		if ( $alignment ) {
			if($alignment == "left"){
				// $custom_styles[] = 'text-align: left;';
				$css_classes .= ' al_left ';
			}elseif($alignment == "center"){
				// $custom_styles[] = 'text-align: center;';
				$css_classes .= ' center ';
			}elseif($alignment == "right"){
				// $custom_styles[] = 'text-align: right;';
				$css_classes .= ' al_right ';
			}
		}

		if ( $color ) {
			$custom_styles[] = 'color: '. $color .';';
		}
		if ( $font_size ) {
			$custom_styles[] = 'font-size: '. $font_size .';';
			if($html_element == 'div' || $html_element == 'p'){
			//	$custom_styles[] = 'line-height: 1.7em;';
			}
		}

		if ( $font_letter_spacing ) {
			$custom_styles[] = 'letter-spacing: '. $font_letter_spacing .';';
		}
		if ( $font_line_height ) {
			$custom_styles[] = 'line-height: '. $font_line_height .';';
		}
		if ( $font_text_transform ) {
			$custom_styles[] = 'text-transform: '. $font_text_transform .';';
		}
		
		if ( $font_italic ) {
			$custom_styles[] = 'font-style: italic;';
		}
		
		if ( $subheading ) {
			$css_classes .= ' boc_subheading';
		}
		// Animated Headline
		if ( $animation_headline ) {
			// If typewriter effect
			if($animation_headline_type == 'typewriter'){
				$css_classes .= ' typewriter '.$animation_words_style;
			}else {
				$css_classes .= ' cd-headline '.$animation_headline_type.' '.$animation_words_style;
			}
		}
		if ( $background ) {
			$css_classes .= " ".$background." ";
		}
		if ( $responsive_font_size ) {
			$css_classes .= " ".$responsive_font_size." ";
		}
		
		$custom_styles = implode('', $custom_styles);

		if ( $custom_styles ) {
			$custom_styles = wp_kses( $custom_styles, array() );
			$custom_styles = ' style="' . esc_attr($custom_styles) . '"';
		}
		
		$delay_tag = ( $delay ? " data-css_delay=".(int)$delay : "");

		return '<'.wp_kses_post($html_element).' class="boc_heading '. esc_attr($css_classes) .' '.esc_attr($css_animation_classes).' '.esc_attr($font_weight).'" '.$custom_styles.' '.$delay_tag.'><span>'.do_shortcode($content).'</span></'.wp_kses_post($html_element).'>';
	}

	add_shortcode('boc_heading', 'boc_shortcode_heading');
}



// Map Shortcode in Visual Composer
vc_map( array(
	"name" 		=> esc_html__("Heading", 'boc-shortcodes-and-widgets'),
	"description" => esc_html__("A custom heading", 'boc-shortcodes-and-widgets'),
	"base" 		=> "boc_heading",
	"icon" 		=> "boc_heading",
	"category" 	=> "Alea Shortcodes",
	"weight"	=> 78,
	"params" => array(
		array(
		 "type" 		=> "textarea",
		 "heading" 		=> "Text",
		 "param_name"	=> "content",
		 "admin_label"	=> true,
		 "value" 		=> "Alea <strong>Heading</strong>  Text",
		 "description"=> "Heading Text. Wrap in a &lt;strong&gt; tag for accent color of heading elements H1-H5"
		),
		array(
			"type"		=> "dropdown",
			"heading"	=> "HTML Element",
			"param_name"	=> "html_element",
			"admin_label"	=> true,
			"value"		=> array(
				"h1"	=> "h1",
				"h2"	=> "h2",
				"h3"	=> "h3",
				"h4"	=> "h4",
				"h5"	=> "h5",
				"div"=> "div",
				"p"	=> "p",
			),
			"std"         => "h2",
			"description"	=> "Select your Heading element type (H1 - H5, etc). To change default design of the element click on Design tab",
		),
		array(
			"type"		=> "dropdown",
			"heading"	=> "Alignment",
			"param_name"	=> "alignment",
			"value"		=> array(
				"Left"	=> "left",
				"Center"=> "center",
				"Right"	=> "right",
			),
			"std"         => "left",
			"description"	=> "Select your Heading alignment",
		),
		array(
			"type"		=> "dropdown",
			"heading"	=> esc_html__("CSS Animation", "boc-shortcodes-and-widgets"),
			"param_name"	=> "css_animation",
			"admin_label"	=> true,				
			"value"			=> array(
				esc_html__("None", "boc-shortcodes-and-widgets")					=> '',
				esc_html__("Top to bottom", "boc-shortcodes-and-widgets")			=> "top-to-bottom",
				esc_html__("Bottom to top", "boc-shortcodes-and-widgets")			=> "bottom-to-top",
				esc_html__("Bottom Unroll", "boc-shortcodes-and-widgets")			=> "bottom-unroll",
				esc_html__("Left to right", "boc-shortcodes-and-widgets")			=> "left-to-right",
				esc_html__("Right to left", "boc-shortcodes-and-widgets")			=> "right-to-left",
				esc_html__("Fade In", "boc-shortcodes-and-widgets")				=> "fade-in",
				esc_html__("Zoom In", "boc-shortcodes-and-widgets")				=> "zoom",
				esc_html__("Zoom Out", "boc-shortcodes-and-widgets")				=> "zoom_out",
				esc_html__("Blur In", "boc-shortcodes-and-widgets")				=> "blur"),
			"description"	=> esc_html__("Select one if you want this element to be animated once it enters the browsers viewport.", "boc-shortcodes-and-widgets"),
			"edit_field_class" =>"vc_col-sm-6",
		),
		array(
			 "type" => "textfield",
			 "heading" => esc_html__("Override Delay (ms)", 'boc-shortcodes-and-widgets'),
			 "param_name" => "delay",
			 "value" => "",
			 "description" => esc_html__("Override the default delay for the CSS animation (e.g. 2000)", 'boc-shortcodes-and-widgets'),
			 "edit_field_class" =>"vc_col-sm-6",
			 "dependency"	=> Array(
				'element'	=> "css_animation",
				'not_empty'	=> true,
			),
		),
		array(
			"type" 		=> "textfield",
			"heading" 	=> "Extra class name",
			"param_name" 	=> "css_classes",
			"description"=> "If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file"
		),			
		array(
			"type"		=> "colorpicker",
			"heading"	=> "Heading Color",
			"param_name"	=> "color",
			"value"		=> "#333",
			"description"	=> "Select your Heading text color. Defaults to dark grey (#333)",
			"group"		=> "Design",	
		),
		array(
			"type"		=> "textfield",
			"heading"	=> "Override Font size",
			"param_name"	=> "font_size",
			"description"	=> "Overwrite default font-size (px), leave out empty for default value of the HTML element you picked",
			"group"		=> "Design",
			"edit_field_class" =>"vc_col-sm-6",
		),
		array(
			"type"		=> "dropdown",
			"heading"	=> "Responsive Font size",
			"param_name"	=> "responsive_font_size",
			"description"	=> "If font size is big (over 40px) make sure you pick a lower value for Responsive",
			"value"		=> array(
				"Inherit"			=> "",
				"10px"				=> "text_10_on_mobile",
				"15px"				=> "text_15_on_mobile",
				"20px"				=> "text_20_on_mobile",
				"25px"				=> "text_25_on_mobile",
				"30px"				=> "text_30_on_mobile",
				"35px"				=> "text_35_on_mobile",
				"40px"				=> "text_40_on_mobile",
				"45px"				=> "text_45_on_mobile",
			),
			"group"		=> "Design",
			"dependency"	=> Array(
				'element'	=> "font_size",
				'not_empty'	=> true,
			),
			"edit_field_class" =>"vc_col-sm-6",
		),
		array(
			"type"		=> "dropdown",
			"heading"	=> "Override Line Height",
			"param_name"	=> "font_line_height",
			"value"		=> array(
				"Inherit"			=> "",
				"1em"				=> "1em",
				"1.1em"				=> "1.1em",
				"1.2em"				=> "1.2em",
				"1.3em"				=> "1.3em",
				"1.4em"				=> "1.4em",
				"1.5em"				=> "1.5em",
				"1.6em"				=> "1.6em",
				"1.7em"				=> "1.7em",
				"1.8em"				=> "1.8em",
				"1.9em"				=> "1.9em",
				"2em"				=> "2em",
			),
			"group"		=> "Design",
			"description"	=> "Override the default line-height",
			"edit_field_class" =>"vc_col-sm-6",
		),
		array(
			"type"		=> "dropdown",
			"heading"	=> "Override Text Transform",
			"param_name"	=> "font_text_transform",
			"value"		=> array(
				"Inherit"			=> "",
				"None"				=> "none",
				"Capitalize"		=> "capitalize",
				"Uppercase"			=> "uppercase",
				"Lowercase"			=> "lowercase",
			),
			"group"		=> "Design",
			"description"	=> "Override the default text-transform",
			"edit_field_class" =>"vc_col-sm-6",
		),
		array(
			"type"		=> "dropdown",
			"heading"	=> "Override Font Weight",
			"param_name"	=> "font_weight",
			"value"		=> array(
				"Inherit"			=> "inherit_weight",
				"Hairline"			=> "hairline_weight",
				"Thin"				=> "thin_weight",
				"Normal"			=> "regular_weight",
				"Semi-Bold"			=> "semibold_weight",
				"Bold"				=> "bold_weight",
				"Bolder"			=> "bolder_weight",
				"W 100"				=> "f100",
				"W 300"				=> "f300",
				"W 400"				=> "f400",
				"W 500"				=> "f500",
				"W 600"				=> "f600",
				"W 700"				=> "f700",
				"W 900"				=> "f900",
			),
			"group"		=> "Design",
			"description"	=> "Make sure the Font supports the font-weight",
			"std"		=> "inherit_weight",
			"edit_field_class" =>"vc_col-sm-6",
		),
		array(
			"type"		=> "dropdown",
			"heading"	=> "Override Letter Spacing",
			"param_name"	=> "font_letter_spacing",
			"value"		=> array(
				"Inherit"			=> "",
				"-0.3em"				=> "-0.3em",
				"-0.2em"				=> "-0.2em",
				"-0.1em"				=> "-0.1em",
				"-0.07em"				=> "-0.07em",
				"-0.05em"				=> "-0.05em",
				"-0.04em"				=> "-0.04em",
				"-0.03em"				=> "-0.03em",
				"-0.02em"				=> "-0.02em",
				"-0.01em"				=> "-0.01em",
				"0em"					=> "0em",
				"0.01em"				=> "0.01em",
				"0.02em"				=> "0.02em",
				"0.03em"				=> "0.03em",
				"0.04em"				=> "0.04em",
				"0.05em"				=> "0.05em",
				"0.07em"				=> "0.07em",
				"0.1em"					=> "0.1em",
				"0.2em"					=> "0.2em",
				"0.3em"					=> "0.3em",
				"0.5em"					=> "0.5em",
			),
			"group"		=> "Design",
			"description"	=> "Override the default letter-spacing",
			"edit_field_class" =>"vc_col-sm-6",
		),
		array(
			"type"		=> 'checkbox',
			"heading"	=> "Italic Font Style",
			"param_name"	=> "font_italic",
			"value"			=> Array(esc_html__("Yes", "boc-shortcodes-and-widgets") => 'yes' ),
			"group"			=> "Design",
			"description"	=> "Make sure the Font supports italic",
			"edit_field_class" =>"vc_col-sm-6",
		),
		array(
			"type"			=> 'checkbox',
			"heading" 		=> esc_html__("Use Subheading Italic Font", 'boc-shortcodes-and-widgets'),
			"param_name" 	=> "subheading",
			"value"			=> Array(esc_html__("Yes", "boc-shortcodes-and-widgets") => 'yes' ),
			"description" 	=> esc_html__("Use default theme subheading font", 'boc-shortcodes-and-widgets'),
			"group"			=> "Design",
			"edit_field_class" =>"vc_col-sm-6",
		),
		array(
			"type"		=> "dropdown",
			"heading"	=> "Custom Background",
			"param_name"	=> "background",
			"value"		=> array(
				"None"				=> "",
				"Diagonal"			=> "bgr_diagonal",
				"Dotted"			=> "bgr_dotted",
				"Multi-Dotted"		=> "bgr_multidotted",
				"Single Line"		=> "bgr_single",
				"Double Line"		=> "bgr_double",
			),
			"description"	=> "Select your Heading alignment",
			"group"		=> "Design",				
		),			
		array(
			"type"			=> "textfield",
			"heading"		=> "Margin Top",
			"param_name"	=> "margin_top",
			"std"			=> "0px",
			"description"	=> "Overwrite default top margin (px), leave out empty for default value of the HTML element you picked",
			"group"			=> "Design",
		),
		array(
			"type"			=> "textfield",
			"heading"		=> "Margin Bottom",
			"param_name"	=> "margin_bot",
			"std"			=> "20px",
			"description"	=> "Overwrite default bottom margin (px), leave out empty for default value of the HTML element you picked",
			"group"			=> "Design",				
		),
		array(
			"type"			=> 'checkbox',
			"heading" 		=> esc_html__("Animated Headline", 'boc-shortcodes-and-widgets'),
			"param_name" 	=> "animation_headline",
			"value"			=> Array(esc_html__("Yes", "boc-shortcodes-and-widgets") => 'yes' ),
			"description" 	=> __("Wrap animated words in &lt;b&gt; tags for example: 'Alea is &lt;b&gt;amazing&lt;/b&gt;&lt;b&gt;awesome&lt;/b&gt;'", 'boc-shortcodes-and-widgets'),
			"group"		=> "Animated Headline",
		),		
		array(
			"type"		=> "dropdown",
			"heading"	=> "Animation Type",
			"param_name"	=> "animation_headline_type",
			"value"		=> array(
				"Clip"				=> "clip",
				"Hand Typing"		=> "type letters",
				"Type Writer"		=> "typewriter",
				"Rotate 1"			=> "rotate-1",
				"Rotate 2"			=> "rotate-2 letters",
				"Rotate 3"			=> "rotate-3 letters",
				"Loading"			=> "loading-bar",
				"Slide"				=> "slide",
				"Zoom"				=> "zoom",
				"Scale"				=> "scale letters",
				"Push"				=> "push",
			),
			"description"	=> "Select your Animation Type",
			"group"		=> "Animated Headline",
			"dependency"	=> Array(
				'element'	=> "animation_headline",
				'not_empty'	=> true,
			)
		),
		array(
			"type"		=> "dropdown",
			"heading"	=> "Override Animated Words Font Weight",
			"param_name"	=> "animation_words_style",
			"value"		=> array(
				"Inherit"			=> "animated_words_inherit",
				"W 100"				=> "i_f100",
				"W 300"				=> "i_f300",
				"W 400"				=> "i_f400",
				"W 500"				=> "i_f500",
				"W 600"				=> "i_f600",
				"W 700"				=> "i_f700",
				"W 900"				=> "i_f900",
			),
			"group"		=> "Animated Headline",
			"description"	=> "Make sure your Heading Font supports the font-weight you pick",
			"std"		=> "animated_words_inherit",
			"dependency"	=> Array(
				'element'	=> "animation_headline",
				'not_empty'	=> true,
			)				
		),
   )
));
