<?php

/**
	Pricing Table Column
**/


// Register Shortcode
if( ! function_exists( 'shortcode_boc_price_column' ) ) {
	function shortcode_boc_price_column($atts, $content = null) {
		
		$atts = vc_map_get_attributes('boc_price_column', $atts );
		extract( $atts );	

		if($featured){
			$css_classes2 .= ' price_column_featured';
		}
		if($add_border){
			$css_classes2 .= ' add_border';
		}
		if($add_shadow){
			$css_classes2 .= ' add_shadow';
		}
		
		// CSS Animation
		$css_animation_classes = "";
		if ( $css_animation !== '' ) {
			$css_animation_classes = 'boc_animate_when_almost_visible boc_'. esc_attr($css_animation) .'';
		}	
		
		$str = '<div class="price_column '.esc_attr($css_classes2).' '.esc_attr($css_animation_classes).'">';
		$str .= '<ul>';
		if($title){
			$str .= '<li class="price_column_title">'.wp_kses_post($title).'</li>';
		}
		if($price){
			$str .= '<li class="price_amount heading_font">'
					.($currency ? '<span class="price_currency">'.wp_kses_post($currency).'</span>':'')
					.wp_kses_post($price)
					.($price_sub ? '<span class="price_sub">'.wp_kses_post($price_sub).'</span>':'')
					.'</li>';
		}
		$str .= '<li>'.do_shortcode($content).'</li>';
		
		if($add_button){
		
			$target 		= ($target 	? " target='".$target."'" : '');
			$icon 			= ($icon 	? " <i class='icon ".esc_attr($icon)."'></i> " : '');
			$icon_pos 		= ($icon 	? $icon_pos : '');
			$icon_effect	= (($icon && $icon_effect!='none' )? $icon_effect : '');
			
			$str .= '<li class="price_button_cell"><a	href="'.esc_url($href).'" 
				class="button '.esc_attr($css_classes.' '.$size.' '.$color.' '.
					$border_radius.' '.$btn_style.' '.$icon_pos.' '.$icon_effect).'" '.$target.'>'.
					(($icon_pos=='icon_pos_before') ? $icon : "").'<span>'.do_shortcode($btn_content).'</span>'.(($icon_pos=='icon_pos_after') ? $icon : "").'</a></li>';  
		}
		
		$str .= '</ul>';
		$str .= '</div>';

		return $str;
	}
	
	add_shortcode('boc_price_column', 'shortcode_boc_price_column');
}

// Map Shortcode in Visual Composer
vc_map( array(
	"name"			=> esc_html__( "Pricing Table", 'boc-shortcodes-and-widgets'),
	"description"	=> esc_html__( "Add a pricing column", 'boc-shortcodes-and-widgets'),
	"base"			=> "boc_price_column",		
	"category" 		=> "Alea Shortcodes",
	"icon" 			=> "boc_price_column",
	"weight"		=> 30,
	"params"		=> array(
		array(
			"type"			=> 'checkbox',
			"heading" 		=> esc_html__('Featured Column?', 'boc-shortcodes-and-widgets'),
			"param_name" 	=> 'featured',
			"value"			=> Array(esc_html__("Yes", "boc-shortcodes-and-widgets") => 'yes' ),
		),
		array(
			"type"			=> "textfield",
			"heading"		=> esc_html__("Title Row", 'boc-shortcodes-and-widgets'),
			"admin_label"	=> true,
			"param_name"	=> "title",
			"value"			=> "Title",
		),
		array(
			"type"			=> "textfield",
			"heading"		=> esc_html__("Currency symbol (before price)", 'boc-shortcodes-and-widgets'),
			"param_name"	=> "currency",
			"value"			=> "$",
		),
		array(
			"type"			=> "textfield",
			"heading"		=> esc_html__("Price", 'boc-shortcodes-and-widgets'),
			"param_name"	=> "price",
			"value"			=> "$49.95",
		),
		array(
			"type"			=> "textfield",
			"heading"		=> esc_html__("Price Subheading", 'boc-shortcodes-and-widgets'),
			"param_name"	=> "price_sub",
			"value"			=> "a month",
		),		
		array(
			"type"			=> "textarea_html",
			"heading"		=> esc_html__("Features", 'boc-shortcodes-and-widgets'),
			"param_name"	=> "content",
			"value"			=> "<ul>
									<li>8 Core Processor</li>
									<li>16 GB Ram</li>
									<li>2 TB Harddrive</li>
								</ul>",
			"description"	=> esc_html__('Enter your pricing column content. Use a UL - LI structure as shown.', 'boc-shortcodes-and-widgets'),
		),
		array(
			"type"			=> 'checkbox',
			"heading" 		=> esc_html__("Add Button link?", 'boc-shortcodes-and-widgets'),
			"param_name" 		=> "add_button",
			"value"			=> Array(esc_html__("Yes", "boc-shortcodes-and-widgets") => 'yes' ),
			"description" 	=> esc_html__("Add a Button to your Pricing Column Bottom. Button properties are set in separate Tabs", 'boc-shortcodes-and-widgets'),
		),
		array(
			"type"			=> 'checkbox',
			"heading" 		=> esc_html__("Add Column Border?", 'boc-shortcodes-and-widgets'),
			"param_name" 		=> "add_border",
			"value"			=> Array(esc_html__("Yes", "boc-shortcodes-and-widgets") => 'yes' ),
			"description" 	=> esc_html__("Add a light grey border for this column?", 'boc-shortcodes-and-widgets'),
		),
		array(
			"type"			=> 'checkbox',
			"heading" 		=> esc_html__("Add Column Shadow?", 'boc-shortcodes-and-widgets'),
			"param_name" 		=> "add_shadow",
			"value"			=> Array(esc_html__("Yes", "boc-shortcodes-and-widgets") => 'yes' ),
			"description" 	=> esc_html__("Add a light grey shadow for this column?", 'boc-shortcodes-and-widgets'),
		),
		array(
			"type"		=> "dropdown",
			"heading"	=> esc_html__("CSS Animation", "boc-shortcodes-and-widgets"),
			"param_name"	=> "css_animation",
			"admin_label"	=> true,				
			"value"			=> array(
				esc_html__("None", "boc-shortcodes-and-widgets")					=> '',
				esc_html__("Top to bottom", "boc-shortcodes-and-widgets")			=> "top-to-bottom",
				esc_html__("Bottom to top", "boc-shortcodes-and-widgets")			=> "bottom-to-top",
				esc_html__("Left to right", "boc-shortcodes-and-widgets")			=> "left-to-right",
				esc_html__("Right to left", "boc-shortcodes-and-widgets")			=> "right-to-left",
				esc_html__("Fade In", "boc-shortcodes-and-widgets")				=> "fade-in",
				esc_html__("Zoom In", "boc-shortcodes-and-widgets")				=> "boc_animate_when_almost_visible boc_zoom",
				esc_html__("Zoom Out", "boc-shortcodes-and-widgets")				=> "boc_animate_when_almost_visible boc_zoom_out",
				esc_html__("Blur In", "boc-shortcodes-and-widgets")				=> "boc_animate_when_almost_visible boc_blur"),
			"description"	=> esc_html__("Select one if you want this element to be animated once it enters the browsers viewport.", "boc-shortcodes-and-widgets"),
		),
		array(
			"type" 			=> "textfield",
			"heading" 		=> esc_html__("Extra class name", 'boc-shortcodes-and-widgets'),
			"param_name" 	=> "css_classes2",
			"description" 	=> esc_html__("If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.", 'boc-shortcodes-and-widgets'),
		),
		

		// Button 
		array(
			"type" => "textfield",
			"heading" => esc_html__("Text", 'boc-shortcodes-and-widgets'),
			"param_name" => "btn_content",
			"value" => esc_html__("Button Text", 'boc-shortcodes-and-widgets'),
			"description" => esc_html__("Enter the text for your Button", 'boc-shortcodes-and-widgets'),
			'group'		=> 'Button Properties',
			"dependency"	=> Array(
				'element'	=> "add_button",
				'not_empty'	=> true,
			)			 
		),
		array(
			"type" => "textfield",
			"heading" => esc_html__("URL Link", 'boc-shortcodes-and-widgets'),
			"param_name" => "href",
			"value" => "",
			"description" => esc_html__("Enter the link you want your button to take you to once clicked.", 'boc-shortcodes-and-widgets'),
			'group'		=> 'Button Properties',
			"dependency"	=> Array(
				'element'	=> "add_button",
				'not_empty'	=> true,
			)			
		),
		array(
			"type" => "dropdown",
			"heading" => esc_html__("Target", 'boc-shortcodes-and-widgets'),
			"param_name" => "target",
			"value" => array('_self','_blank'),
			"description" => esc_html__("Pick '_blank' if you want the button link to open in a new tab.", 'boc-shortcodes-and-widgets'),
			'group'		=> 'Button Properties',
			"dependency"	=> Array(
				'element'	=> "add_button",
				'not_empty'	=> true,
			)			
		),
		array(
			"type" => "textfield",
			"heading" => esc_html__("Extra class name", 'boc-shortcodes-and-widgets'),
			"param_name" => "css_classes",
			"value" => "",
			"description" => esc_html__("If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.", 'boc-shortcodes-and-widgets'),
			"group"		=> 'Button Properties',
			"dependency"	=> Array(
				'element'	=> "add_button",
				'not_empty'	=> true,
			)	
		),		  
		array(
			"type"			=> "dropdown",
			"heading"		=> "Button Size",
			"param_name"		=> "size",
			"value"			=> array(
				"Small" => "btn_small",
				"Medium"=> "btn_medium",
				"Large" => "btn_large",
				"Huge"  => "btn_huge",
				"Stretched Small" => "btn_small_stretched",
				"Stretched Medium"=> "btn_medium_stretched",
				"Stretched Large" => "btn_large_stretched",
				"Stretched Huge"  => "btn_huge_stretched",
			),
			"std"			=> "btn_medium",
			"description"	=> "Select a size",
			'group'			=> 'Button Design',
			"dependency"	=> Array(
				'element'	=> "add_button",
				'not_empty'	=> true,
			)			
		),
		array(
			"type"			=> "dropdown",
			"heading"		=> "Button Color",
			"param_name"		=> "color",
			"admin_label"	=> true,
			"value"			=> array(
				"Theme Color"	=> "btn_theme_color",
				"Dark" 			=> "btn_dark",
				"White" 		=> "btn_white",
				"Blue" 			=> "btn_blue",
				"Bondi Blue"	=> "btn_bondi",
				"Royal Blue"	=> "btn_royalblue",
				"Turquoise" 	=> "btn_turquoise",
				"Azure"			=> "btn_azure",
				"Green" 		=> "btn_green",
				"Lime Green"	=> "btn_limegreen",
				"Emerald" 		=> "btn_emerald",
				"Jade"	 		=> "btn_jade",
				"Orange"		=> "btn_orange",
				"Yellow"		=> "btn_yellow",
				"Purple"		=> "btn_purple",
				"Plum"		=> "btn_plum",
				"Magenta"	=> "btn_magenta",
				"Red"		=> "btn_red",
				"Apple"		=> "btn_apple",
				"Pink"		=> "btn_pink",
				"Brown"		=> "btn_brown",
				"Simple Link"	=> "btn_no_bgr",				
			),
			"description"	=> "Select a button color. They are predefined for a number of reasons, like text color, hover effects etc. Use the CSS class option to define your own.",
			'group'			=> 'Button Design',
			"dependency"	=> Array(
				'element'	=> "add_button",
				'not_empty'	=> true,
			)			
		),
		array(
			"type"		=> "dropdown",
			"heading"	=> "Button Style",
			"param_name"	=> "btn_style",
			"value"		=> array(
				"Normal" 	=> "btn_normal_style", // Default
				"Gradient" 	=> "btn_gradient",
				"Outline" 	=> "btn_outline",
				"3D"	 		=> "btn_3d",
			),
			"description"	=> "Select a style",
			'group'		=> 'Button Design',
			"dependency"	=> Array(
				'element'	=> "add_button",
				'not_empty'	=> true,
			)			
		),			
		array(
			"type"		=> "dropdown",
			"heading"	=> "Border Radius",
			"param_name"	=> "border_radius",
			"value"		=> array(
				"Rounded" => "btn_rounded",
				"Sqaured" => "btn_squared",
				"Circled" => "btn_circled",
			),
			"description"	=> "Select a border radius style",
			'group'			=> 'Button Design',
			"dependency"	=> Array(
				'element'	=> "add_button",
				'not_empty'	=> true,
			)			
		),
		array(
			"type" 		=> "iconpicker",
			"heading" 	=> "Add Button Icon",
			"param_name"=> "icon",
			"settings" 		=> array(
				'type'      => 'alea',
				'emptyIcon' => true, // default true, display an "EMPTY" icon?
				'iconsPerPage' => 4000, // default 100, how many icons per/page to display, we use (big number) to display all icons in single page
			),
			"value" 	=> "",
			"description"=> "Type in an icon name from the list to add an icon to the button text.",
			'group'		=> 'Button Icon',
			"dependency"	=> Array(
				'element'	=> "add_button",
				'not_empty'	=> true,
			)			
		),
		array(
			"type" => "dropdown",
			"heading" => "Icon Position",
			"param_name" => "icon_pos",
			"value"			=> array(
				"Before Text" => "icon_pos_before",
				"After Text" => "icon_pos_after",
			),
			"description" => "Choose a position for the icon",
			'group'		=> 'Button Icon',
			"dependency"	=> Array(
				'element'	=> "add_button",
				'not_empty'	=> true,
			)
		),
		array(
			"type"		=> "dropdown",
			"heading"	=> "Icon Effect",
			"param_name"	=> "icon_effect",
			"value"		=> array(
				"None" 		=> "none",
				"Animate In" 	=> "btn_icon_anim_in",
				"Animate Out" => "btn_icon_anim_out",
			),
			"description"	=> "Select an Icon Animate Effect if you want one",
			"group"		=> 'Button Icon',
			"dependency"	=> Array(
				'element'	=> "add_button",
				'not_empty'	=> true,
			)
		)

	)
));