<?php

/**
	Icon Shortcode - part of the Theme Base -> shortcodes.php
**/


// Font Icon 
if( ! function_exists( 'shortcode_vc_boc_social_icon' ) ) {
	function shortcode_vc_boc_social_icon($atts, $content = null) {
		
			$atts = vc_map_get_attributes('boc_social_icon', $atts );
			extract( $atts );
		
			$link = '';
			if($href){
				$link = '<a href="'.esc_url($href).'" target="'.esc_attr($target).'" class="boc_social_icon_holder_link '. esc_attr($size) .'">';
			}
			
			$css_animation_classes = '';
			if ( $css_animation !== '' ) {
				$css_animation_classes = 'boc_animate_when_almost_visible boc_'. $css_animation .'';
			}
			$delay_tag = ( $delay ? " data-css_delay=".(int)$delay : "");
			
			$str = $href ? $link : '';
			$str .= '<div class="boc_social_icon_holder boc_social_icon_size_'. esc_attr($size) .' boc_social_icon_style_'. esc_attr($style) .' '. esc_attr($css_animation_classes) .' '.esc_attr($css_classes).'" '.$delay_tag.'><span class="boc_social_icon '. esc_attr($icon) .'"></span></div>';
			
			$str .= $href ? '</a>' : '';

			return $str;
	}
	
	add_shortcode('boc_social_icon', 'shortcode_vc_boc_social_icon');
}

// Map Shortcode in Visual Composer
vc_map( array(
	"name"		=> "Social Icon",
	"description" => esc_html__("Icon with custom Link", 'boc-shortcodes-and-widgets'),
	"base"		=> "boc_social_icon",
	"icon"		=> "boc_social_icon",
	"category" 	=> "Alea Shortcodes",
	"weight"	=> 18,
	"params"	=> array(
		array(
			"type"          => "iconpicker",
			"heading"       => "Icon",
			"param_name"    => "icon",
			"admin_label"   => true,
			"settings" => array(
				'type' 		=> 'alea',
				'emptyIcon' => false, // default true, display an "EMPTY" icon?
				'iconsPerPage' => 2000, // default 100, how many icons per/page to display, we use (big number) to display all icons in single page
			),
			'description' 	=> esc_html__( 'Select icon from library.', 'boc-shortcodes-and-widgets' ),
		),
		array(
			"type" => "textfield",
			"heading" => esc_html__("URL Link", "boc-shortcodes-and-widgets"),
			"param_name" => "href",
			"description" => esc_html__("Enter a link if you want one. Don't forget the http:// in front.", "boc-shortcodes-and-widgets"),
		),
		array(
			"type" => "dropdown",
			"heading" => esc_html__("Target", "boc-shortcodes-and-widgets"),
			"param_name" => "target",
			"value" => array('_self','_blank'),
			"description" => esc_html__("Pick '_blank' if you want the link to open in a new tab.", "boc-shortcodes-and-widgets"),
		),
		array(
			"type"			=> "dropdown",
			"class"			=> "",
			"heading"		=> esc_html__( "Icon Size", 'boc-shortcodes-and-widgets' ),
			"param_name"	=> "size",
			"description"	=> esc_html__( "Select an icon size.", 'boc-shortcodes-and-widgets' ),
			"value"			=> array(
				esc_html__( "Small", "boc-shortcodes-and-widgets")		=> "small",
				esc_html__( "Normal", "boc-shortcodes-and-widgets" )		=> "normal",
				esc_html__( "Large", "boc-shortcodes-and-widgets" )		=> "large",
			),
			"std"			=> "normal",
		),
		array(
			"type"			=> "dropdown",
			"class"			=> "",
			"heading"		=> esc_html__( "Icon Style", 'boc-shortcodes-and-widgets' ),
			"param_name"	=> "style",
			"description"	=> esc_html__( "Select a style preset. Use CSS for further styling.", 'boc-shortcodes-and-widgets' ),
			"value"			=> array(
				esc_html__( "Light", "boc-shortcodes-and-widgets")		=> "light",
				esc_html__( "Dark", "boc-shortcodes-and-widgets" )		=> "dark",
				esc_html__( "Minimal", "boc-shortcodes-and-widgets" )		=> "minimal",
			),
			"std"			=> "light",
		),
		array(
			"type"		=> "dropdown",
			"heading"	=> esc_html__("CSS Animation", "boc-shortcodes-and-widgets"),
			"param_name"	=> "css_animation",
			"admin_label"	=> true,				
			"value"			=> array(
				esc_html__("None", "boc-shortcodes-and-widgets")					=> '',
				esc_html__("Top to bottom", "boc-shortcodes-and-widgets")			=> "top-to-bottom",
				esc_html__("Bottom to top", "boc-shortcodes-and-widgets")			=> "bottom-to-top",
				esc_html__("Left to right", "boc-shortcodes-and-widgets")			=> "left-to-right",
				esc_html__("Right to left", "boc-shortcodes-and-widgets")			=> "right-to-left",
				esc_html__("Fade In", "boc-shortcodes-and-widgets")				=> "fade-in",
				esc_html__("Zoom In", "boc-shortcodes-and-widgets")				=> "zoom",
				esc_html__("Zoom Out", "boc-shortcodes-and-widgets")				=> "zoom_out",
				esc_html__("Blur In", "boc-shortcodes-and-widgets")				=> "blur"),
			"description"	=> esc_html__("Select one if you want this element to be animated once it enters the browsers viewport.", "boc-shortcodes-and-widgets"),
			"edit_field_class" =>"vc_col-sm-6",
		),
		array(
			 "type" => "textfield",
			 "heading" => esc_html__("Override Delay (ms)", 'boc-shortcodes-and-widgets'),
			 "param_name" => "delay",
			 "value" => "",
			 "description" => esc_html__("Override the default delay for the CSS animation (e.g. 2000)", 'boc-shortcodes-and-widgets'),
			 "edit_field_class" =>"vc_col-sm-6",
			 "dependency"	=> Array(
				'element'	=> "css_animation",
				'not_empty'	=> true,
			),
		),	
		array(
			"type" => "textfield",
			"heading" => esc_html__("Extra class name", 'boc-shortcodes-and-widgets'),
			"param_name" => "css_classes",
			"value" => "",
			"description" => esc_html__("If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.", 'boc-shortcodes-and-widgets'),
		),
	)
));
