<?php

/**
	Divider
**/

// Register Shortcode
if( ! function_exists( 'boc_shortcode_divider' ) ) {
	function boc_shortcode_divider( $atts )
    {


        $atts = vc_map_get_attributes('boc_divider', $atts);
        extract($atts);

        // CSS Animation
        $css_animation_classes = "";
        if ($css_animation != '') {
            $css_animation_classes = 'boc_animate_when_almost_visible boc_' . $css_animation . '';
        }
		$delay_tag = ( $delay ? " data-css_delay=".(int)$delay : "");

        $custom_styles = array();

        if ($margin_top) {
            $custom_styles[] = 'margin-top: ' . $margin_top . ';';
        }
        if ($margin_bot) {
            $custom_styles[] = 'margin-bottom: ' . $margin_bot . ';';
        }

        // normal
        if ($type == 'normal'){

            if ($divider_width) {
                $custom_styles[] = 'width: ' . $divider_width . ';';
                if ($divider_position == "center") {
                    $custom_styles[] = 'margin-left: auto; margin-right: auto;';
                } elseif ($divider_position == "right") {
                    $custom_styles[] = 'float: right;';
                    $css_classes .= ' divider_right';
                }
            }
            if ($divider_height) {
                $custom_styles[] = 'height: ' . $divider_height . ';';
            }
            if ($divider_color) {
                $custom_styles[] = 'background: ' . $divider_color . ';';
            }

            $custom_styles = implode('', $custom_styles);

            if ($custom_styles) {
                $custom_styles = wp_kses($custom_styles, array());
                $custom_styles = ' style="' . esc_attr($custom_styles) . '"';
            }

            // Icon Style
            $icon_style = array();

            if ($icon) {

                if ($icon_size) {
                    $icon_style[] = 'font-size: ' . $icon_size . '; line-height: ' . $icon_size . ';';
                }
                if ($icon_color && $icon_color !== '#eeeeee') {
                    $icon_style[] = 'color: ' . $icon_color . ';';
                }
				if ( $icon_position == 'center') {
					$icon_style[] = 'left: 50%; transform: translateY(-50%) translateX(-50%);';
				}
				if ( $icon_position == 'right') {
					$icon_style[] = 'left: 100%; transform: translateY(-50%) translateX(-100%);';
				}
                if ($icon_bg) {
                    $icon_style[] = 'background-color: ' . $icon_bg . ';';
                }
                if ($icon_bg_border) {
                    $icon_style[] = 'border: 1px solid ' . $icon_bg_border . ';';
                }
                if ($icon_padding) {
                    $icon_style[] = 'padding: ' . $icon_padding . ';';
                }
                $icon_style = implode('', $icon_style);
            }

            if ($icon_style) {
                $icon_style = wp_kses($icon_style, array());
                $icon_style = ' style="' . esc_attr($icon_style) . '"';
            }

            // Output
            if ($icon) {
                $str = '<div '.$delay_tag.' class="boc_divider ' . esc_attr($css_classes) . ' ' . esc_attr($css_animation_classes) . '" ' . $custom_styles . '><i class="icon ' . esc_attr($icon) . '" ' . $icon_style . '></i></div>';
            } else {
                $str = '<div '.$delay_tag.' class="boc_divider ' . esc_attr($css_classes) . ' ' . esc_attr($css_animation_classes) . '" ' . $custom_styles . '></div>';
            }

        // Zigzag
        }else {
            $unique_id = rand(1,100000);
            if ($divider_width_zigzag) {
                $custom_styles[] = 'width: ' . $divider_width_zigzag . ';';
				
				$custom_styles[] = 'background: repeat-x url(\'data:image/svg+xml;utf-8,<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/2000/svg" width="14px" height="6px" viewBox="-1.75 -0.375 14 6" xml:space="preserve"><polygon points="5.25,3.853 -1.75,-0.194 -1.75,1.203 5.25,5.25 12.25,1.203 12.25,-0.194 " fill="'.urlencode($divider_color).'"/></svg>\');';
				
                if ($divider_position == "center") {
                    $custom_styles[] = 'margin-left: auto; margin-right: auto;';
                } elseif ($divider_position == "right") {
                    $custom_styles[] = 'float: right;';
                }
            }

            if ($size == 'medium') {
                $custom_styles[] = 
					(($divider_position == "left") ? 'transform-origin: 0% 0%;' : '') . 
					(($divider_position == "center") ? 'transform-origin: 50% 50%;' : '') . 
					(($divider_position == "right") ? 'transform-origin: 100% 100%;' : '') . 
					'transform: scale(1.3) translateY(1px); height: 8px; ';
            }
            if ($size == 'large') {
                $custom_styles[] = 
					(($divider_position == "left") ? 'transform-origin: 0% 0%;' : '') . 
					(($divider_position == "center") ? 'transform-origin: 50% 50%;' : '') . 
					(($divider_position == "right") ? 'transform-origin: 100% 100%;' : '') . 
					'transform: scale(1.5) translateY(1px); height: 9px;';
            }

            $custom_styles = implode('', $custom_styles);
            if ($custom_styles) {
                $custom_styles = esc_attr($custom_styles, array());
                $custom_styles = ' style="height: 6px;' . esc_attr($custom_styles).'"';
            }

            $str = '<div '.$delay_tag.' id="zz_'.$unique_id.'" class="boc_divider zigzag ' . esc_attr($css_classes) . ' ' . esc_attr($css_animation_classes) . '" ' . $custom_styles . '></div>';

        }

		
		return $str;
	}
	
	add_shortcode( 'boc_divider', 'boc_shortcode_divider' );
}


// Map Shortcode in Visual Composer
vc_map( array(
	"name"				=> "Divider",
	"description"		=> "Custom Separator",
	"base"				=> "boc_divider",
	"icon" 				=> "boc_divider",
	'category'			=> "Alea Shortcodes",
	"weight"			=> 73,
	"params"				=> array(
        array(
            "type"		=> "dropdown",
            "heading"	=> "Type",
            "param_name"	=> "type",
            "value"		=> array(
                "Normal"	=> "normal",
                "ZigZag"	=> "zigzag",
            ),
            "std"	=> "normal",
        ),
		array(
			"type"		=> "dropdown",
			"heading"	=> "Width",
			"param_name"	=> "divider_width",
			"value"		=> array(
				"100%"	=> "",
				"80%"	=> "80%",
				"60%"	=> "60%",
				"50%"	=> "50%",
				"200px"	=> "200px",
				"150px"	=> "150px",
				"100px"	=> "100px",
				"60px"	=> "60px",
				"50px"	=> "50px",
				"40px"	=> "40px",
			),
			"std"	=> "",
			"description"	=> "Select your divider width. Can be either relative to its container (%) or a fixed width (px)",
            "dependency"		=> array(
                'element'	=> "type",
                'value'		=> array("normal"),
            ),
        ),
		array(
			"type"		=> "dropdown",
			"heading"	=> "Width",
			"param_name"	=> "divider_width_zigzag",
			"value"		=> array(
				"100%"	=> "",
				"50%"	=> "50%",
				"280px"	=> "280px",
				"140px"	=> "140px",
				"98px"	=> "98px",
				"70px"	=> "70px",
				"56px"	=> "56px",
				"42px"	=> "42px",
			),
			"std"	=> "",
			"description"	=> "Select your divider width. Can be either relative to its container (%) or a fixed width (px)",
            "dependency"		=> array(
                'element'	=> "type",
                'value'		=> array("zigzag"),
            ),
        ),
		array(
			"type"		=> "dropdown",
			"heading"	=> "Alignment",
			"param_name"	=> "divider_position",
			"value"		=> array(
				"Left"	=> "left",
				"Center"	=> "center",
				"Right"	=> "right",
			),
			"std"	=> "left",
			"description"	=> "Select your divider position if smaller than 100%.",
		),			
		array(
			"type"		=> "dropdown",
			"heading"	=> "Height",
			"param_name"	=> "divider_height",
			"value"		=> array(
				"1px"	=> "1px",
				"2px"	=> "2px",
				"3px"	=> "3px",
				"4px"	=> "4px",
				"6px"	=> "6px",
			),
			"std"		=> "1px",
			"description"	=> "Select your divider height in px",
            "dependency"		=> array(
                'element'	=> "type",
                'value'		=> array("normal"),
            ),
		),
        array(
            "type"		=> "dropdown",
            "heading"	=> "Zigzag Size",
            "param_name"	=> "size",
            "value"		=> array(
                "Small" => "small",
                "Medium"=> "medium",
                "Large"	=> "large",
            ),
            "std"		=> "small",
            "description"	=> "Select your zigzag line size",
            "dependency"		=> array(
                'element'	=> "type",
                'value'		=> array("zigzag"),
            ),
        ),
		array(
			"type"		=> "colorpicker",
			"heading"	=> "Divider Color",
			"param_name"	=> "divider_color",
			"value"		=> "#eee",
			"description"	=> "Select your divider color. Defaults to bright grey (#eeeeee)",
		),			
		array(
			"type"		=> "textfield",
			"heading"	=> "Margin Top",
			"param_name"	=> "margin_top",
			"std"		=> "20px",
			"description"	=> "Enter a top margin for your divider in pixels. Enter 0 for none.",
		),
		array(
			"type"		=> "textfield",
			"heading"	=> "Margin Bottom",
			"param_name"	=> "margin_bot",
			"std"		=> "20px",
			"description"	=> "Enter a bottom margin for your divider in pixels. Enter 0 for none.",
		),
		array(
			"type"		=> "dropdown",
			"heading"	=> esc_html__("CSS Animation", "boc-shortcodes-and-widgets"),
			"param_name"	=> "css_animation",
			"admin_label"	=> true,
			"value"			=> array(
				esc_html__("None", "boc-shortcodes-and-widgets")					=> '',
				esc_html__("Top to bottom", "boc-shortcodes-and-widgets")			=> "top-to-bottom",
				esc_html__("Bottom to top", "boc-shortcodes-and-widgets")			=> "bottom-to-top",
				esc_html__("Left to right", "boc-shortcodes-and-widgets")			=> "left-to-right",
				esc_html__("Right to left", "boc-shortcodes-and-widgets")			=> "right-to-left",
				esc_html__("Fade In", "boc-shortcodes-and-widgets")				=> "fade-in",
				esc_html__("Zoom In", "boc-shortcodes-and-widgets")				=> "zoom",
				esc_html__("Zoom Out", "boc-shortcodes-and-widgets")				=> "zoom_out",
				esc_html__("Blur In", "boc-shortcodes-and-widgets")				=> "blur"),
			"description"	=> esc_html__("Select one if you want this element to be animated once it enters the browsers viewport.", "boc-shortcodes-and-widgets"),
			"edit_field_class" =>"vc_col-sm-6",
		),
		array(
			 "type" => "textfield",
			 "heading" => esc_html__("Override Delay (ms)", 'boc-shortcodes-and-widgets'),
			 "param_name" => "delay",
			 "value" => "",
			 "description" => esc_html__("Override the default delay for the CSS animation (e.g. 2000)", 'boc-shortcodes-and-widgets'),
			 "edit_field_class" =>"vc_col-sm-6",
			 "dependency"	=> Array(
				'element'	=> "css_animation",
				'not_empty'	=> true,
			),
		),
		array(
			"type" 			=> "textfield",
			"heading" 		=> "Extra class name",
			"param_name" 	=> "css_classes",
			"description" 	=> "If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file"
		),
		array(
			"type"          => "iconpicker",
			"heading"       => "Icon",
			"param_name"    => "icon",
			"admin_label"   => true,
			"settings" => array(
				'type' => 'alea',
				'emptyIcon' => true, // default true, display an "EMPTY" icon?
				'iconsPerPage' => 4000, // default 100, how many icons per/page to display, we use (big number) to display all icons in single page
			),
			'description'   => esc_html__( 'Select icon from library.', 'boc-shortcodes-and-widgets' ),
			"group"         => esc_html__( 'Icon', 'boc-shortcodes-and-widgets' ),
            "dependency"		=> array(
                'element'	=> "type",
                'value'		=> array("normal"),
            ),
		),		
		
		array(
			"type"		=> "dropdown",
			"heading"	=> "Icon Position",
			"param_name"=> "icon_position",
			"value"		=> array(
				"Left"	=> "left",
				"Center"=> "center",
				"Right"	=> "right",
			),
			"std"        => "center",
            "dependency" => array(
                'element'	=> "icon",
                'not_empty'	=> true,
            ),
			"description"	=> "Select your icon position",
			"group"		=> "Icon",
		),
		array(
			"type"		=> "colorpicker",
			"heading"	=> "Icon Color",
			"param_name"=> "icon_color",
			"value"		=> "#bbbbbb",
            "dependency"=> array(
                'element'	=> "icon",
                'not_empty'	=> true,
            ),
			"group"		=> "Icon",
		),
		array(
			"type"		=> "colorpicker",
			"heading"	=> "Icon Background",
			"param_name"	=> "icon_bg",
			"value"		=> "#ffffff",
            "dependency"=> array(
                'element'	=> "icon",
                'not_empty'	=> true,
            ),
			"group"		=> "Icon",
		),	
		array(
			"type"		=> "colorpicker",
			"heading"	=> "Icon Background Border",
			"param_name"	=> "icon_bg_border",
			"value"		=> "",
            "dependency"=> array(
                'element'	=> "icon",
                'not_empty'	=> true,
            ),
			"group"		=> "Icon",
		),			
		array(
			"type"		=> "textfield",
			"heading"	=> "Icon Size",
			"param_name"	=> "icon_size",
			"value"		=> "14px",
            "dependency"=> array(
                'element'	=> "icon",
                'not_empty'	=> true,
            ),
			"description"	=> "Enter a custom icon size in pixels for your divider icon. Default is 14px",
			"group"		=> "Icon",
		),
		array(
			"type"		=> "textfield",
			"heading"	=> "Icon Padding",
			"param_name"	=> "icon_padding",
			"value"		=> "10px",
            "dependency"=> array(
                'element'	=> "icon",
                'not_empty'	=> true,
            ),
			"description"	=> "Change the default padding of the icon. Default is 10px",
			"group"		=> "Icon",				
		),			
	)
));	