<?php

/**
	Image Box
**/

// Register Shortcode
if( ! function_exists( 'shortcode_boc_image_box' ) ) {
	function shortcode_boc_image_box($atts, $content = null) {

		$atts = vc_map_get_attributes('boc_image_box', $atts );
		extract( $atts );

		// Img Hover Effect
		if ($img_hover_effect){
			$img_hover_effect = ' img_hover_effect'.$img_hover_effect;
		}

		// Display Type
		$design_style = 'type'.$display_style;
		
		// Pic
		$img = '';
		if($picture){
			$vc_image = wp_get_attachment_image($picture,'boc_medium');
			
			// If not passed via VC, we use default Person Icon
			if($vc_image){
				$img = $vc_image;
			}else {
				$img = '';
			}
		}else {
				$img = '';
		}
		
		// CSS Animation
		$css_animation_classes = "";
		if ( $css_animation !== '' ) {
			$css_animation_classes = 'boc_animate_when_almost_visible boc_'. $css_animation .'';
		}
		$delay_tag = ( $delay ? " data-css_delay=".(int)$delay : "");

		if($centered) {
			$css_classes .= ' center';
		}		
		
		if($shadow) {
			$css_classes .= ' shadowed';
		}
		
		$feat_img = '';
		
		// Image
		if($picture){		
			if($img_width && $img_height){
				$featured_img_url	= wp_get_attachment_url( $picture );
				$thumbnail_hard_crop = true;
				$new_feat_img_url = aq_resize( $featured_img_url, intval($img_width), intval($img_height), $thumbnail_hard_crop );
				$feat_img = '<img src="'.esc_url($new_feat_img_url).'" alt="'.esc_attr(get_post_meta(get_post_thumbnail_id(), "_wp_attachment_image_alt", true)).'">';
			}else{
				$feat_img = wp_get_attachment_image($picture,'boc_medium');
			}
		}
		
		$cursor_default_style = '';

		if($href == '') {
			$href = 'javascript:void(0)';
			$cursor_default_style = ' style="cursor: default;"'; 
		}else {
			$href = esc_url($href);
		}
		
		$str =
			'
				<a href="'.$href.'" '.$cursor_default_style.' class="pic_info_link_'.esc_attr($design_style).'">
				  <div class="boc_image_box '.esc_attr($css_classes).' '.$css_animation_classes.'" '.$delay_tag.'>
					<div class="pic_info '.esc_attr($design_style).'">
						<div class="pic '.esc_attr($img_hover_effect).'"><div class="plus_overlay"></div><div class="plus_overlay_icon"></div>
						'.$feat_img.'
						<div class="img_overlay_icon"><span class="portfolio_icon icon_link"></span></div></div>
						'.(($title||$content) ? '
						<div class="info_overlay">
							<div class="info_overlay_padding">
								<div class="info_desc">
									<span class="portfolio_icon icon_link"></span>
									<h3>'.wp_kses_post($title).'</h3>
									<section>'.do_shortcode(boc_remove_wpautop($content)).'</section>
								</div>
							</div>
						</div>': '').'
					</div>
				  </div>
				</a>
			';


		return $str;
	}
	
	add_shortcode('boc_image_box', 'shortcode_boc_image_box');
}



// Map Shortcode in Visual Composer
vc_map( array(
   "name" => esc_html__("Image Box", 'boc-shortcodes-and-widgets'),
   "description" => esc_html__("Image + Text + Effects", 'boc-shortcodes-and-widgets'),
   "base" => "boc_image_box",
   "category" => "Alea Shortcodes",
   "icon" 	=> "boc_img_box",
   "weight"	=> 61,
   "params" => array(
		array(
			"type" 			=> "attach_image",
			"heading" 		=> esc_html__("Image", 'boc-shortcodes-and-widgets'),
			"param_name" 	=> "picture",
			"description" 	=> esc_html__("Add an Image", 'boc-shortcodes-and-widgets'),
			"group"			=> "Box Settings",
		),   
   		array(
			"type"			=> "textfield",
			"heading"		=> esc_html__("Image Box Title", 'boc-shortcodes-and-widgets'),
			"admin_label"	=> true,
			"param_name"	=> "title",
			"value"			=> "Title",
			"group"			=> "Box Settings",			
		),
		array(
			"type"			=> "textarea_html",
			"heading"		=> esc_html__("Image Box Sub Title", 'boc-shortcodes-and-widgets'),
			"param_name"	=> "content",
			"value"			=> "Sub Title",
			"group"			=> "Box Settings",			
		),
		array(
			"type"			=> 'checkbox',
			"heading"		=> esc_html__("Center Texts?", "boc-shortcodes-and-widgets"),
			"param_name"	=> "centered",
			"value"			=> Array(esc_html__("Yes", "boc-shortcodes-and-widgets") => 'yes' ),
			"description"	=> esc_html__("Check if you want the box texts centered.", "boc-shortcodes-and-widgets"),
			"group"			=> "Box Settings",
		),
		array(
			"type" 			=> "textfield",
			"heading" 		=> esc_html__("URL Link", 'boc-shortcodes-and-widgets'),
			"param_name" 	=> "href",
			"value" 		=> "",
			"description" 	=> esc_html__("Enter a link if you want one for the image box", 'boc-shortcodes-and-widgets'),
			"group"			=> "Box Settings",			
		),
		array(
			"type" 		=> "dropdown",
			"heading" 		=> esc_html__("Target", 'boc-shortcodes-and-widgets'),
			"param_name" 	=> "target",
			"value" 		=> array('_self','_blank'),
			"dependency"	=> array(
				'element'	=> "href",
				'not_empty'	=> true,
			), 
			"description" 	=> esc_html__("Pick '_blank' if you want the link to open in a new tab.", 'boc-shortcodes-and-widgets'),
			"group"			=> "Box Settings",
		),
		array(
			"type"		=> "dropdown",
			"heading"	=> esc_html__("CSS Animation", "boc-shortcodes-and-widgets"),
			"param_name"	=> "css_animation",
			"admin_label"	=> true,				
			"value"			=> array(
				esc_html__("None", "boc-shortcodes-and-widgets")					=> '',
				esc_html__("Top to bottom", "boc-shortcodes-and-widgets")			=> "top-to-bottom",
				esc_html__("Bottom to top", "boc-shortcodes-and-widgets")			=> "bottom-to-top",
				esc_html__("Left to right", "boc-shortcodes-and-widgets")			=> "left-to-right",
				esc_html__("Right to left", "boc-shortcodes-and-widgets")			=> "right-to-left",
				esc_html__("Fade In", "boc-shortcodes-and-widgets")				=> "fade-in",
				esc_html__("Zoom In", "boc-shortcodes-and-widgets")				=> "zoom",
				esc_html__("Zoom Out", "boc-shortcodes-and-widgets")				=> "zoom_out",
				esc_html__("Blur In", "boc-shortcodes-and-widgets")				=> "blur"),
			"description"	=> esc_html__("Select one if you want this element to be animated once it enters the browsers viewport.", "boc-shortcodes-and-widgets"),
			"edit_field_class" =>"vc_col-sm-6",
			"group"			=> "Box Settings",
		),
		array(
			"type" => "textfield",
			"heading" => esc_html__("Override Delay (ms)", 'boc-shortcodes-and-widgets'),
			"param_name" => "delay",
			"value" => "",
			"description" => esc_html__("Override the default delay for the CSS animation (e.g. 2000)", 'boc-shortcodes-and-widgets'),
			"edit_field_class" =>"vc_col-sm-6",
			"dependency"	=> Array(
				'element'	=> "css_animation",
				'not_empty'	=> true,
			),
			"group"			=> "Box Settings",
		),
		array(
			"type" 			=> "textfield",
			"heading" 		=> esc_html__("Extra class name", 'boc-shortcodes-and-widgets'),
			"param_name" 	=> "css_classes",
			"description" 	=> esc_html__("If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.", 'boc-shortcodes-and-widgets'),
			"group"			=> "Box Settings",
		),

		array(
			"type" 			=> "dropdown",
			"heading" 		=> esc_html__("Display Style", 'boc-shortcodes-and-widgets'),
			"param_name" 	=> "display_style",
			"value" 		=> array(
					"Diagonal Unroll (1)"		=> '1',
					"Overlay Fade (2)"	 		=> '2',
					"Overlay Fade Up (3)" 		=> '3',
					"Circular Explode (4)" 		=> '4',
					"Text Overlay (5)"		 	=> '5',
					"Rotate (6)"			 	=> '6',
					"Color Overlay Text (7)"	=> '7',
					"Dark Overlay Text (8)"		=> '8'
			),
			"description" 	=> esc_html__("Pick a Display Style. Explore them all to see what best fits your needs.", 'boc-shortcodes-and-widgets'),
			"group"			=> "Design",
		),
		array(
			"type"			=> 'dropdown',
			"heading" 		=> esc_html__("Hover Image Effect", 'boc-shortcodes-and-widgets'),
			"param_name" 	=> "img_hover_effect",
			"value"			=> Array("None" => '', "Zoom Out" => 1, "Zoom In" => 2, "Side" => 3, "Spin" => 4),
			"description" 	=> esc_html__("Pick a hover Image Effect", 'boc-shortcodes-and-widgets'),
			"group"			=> "Design",
		),
		array(
			"type"			=> 'checkbox',
			"heading"		=> esc_html__("Add Shadow?", "boc-shortcodes-and-widgets"),
			"param_name"	=> "shadow",
			"value"			=> Array(esc_html__("Yes", "boc-shortcodes-and-widgets") => 'yes' ),
			"group"			=> "Design",
		),		
		array(
			'type'			=> "textfield",
			"heading"		=> esc_html__( "Overwrite Image Width", 'boc-shortcodes-and-widgets'),
			'param_name'	=> "img_width",
			'std'			=> "",
			'description'	=> esc_html__( "Enter a width in pixels if you want to overwrite the default (600x380). Both W and H should be changed to define a new dimension. Leave empty for default.", 'boc-shortcodes-and-widgets'),
			'group'			=> "Design",
		),
		array(
			'type'			=> "textfield",
			"heading"		=> esc_html__( "Overwrite Image Height", 'boc-shortcodes-and-widgets'),
			'param_name'	=> "img_height",
			'std'			=> "",
			'description'	=> esc_html__( 'Enter a height in pixels if you want to overwrite the default (380). Both W and H should be changed to define a new dimension. Leave empty for default.', 'boc-shortcodes-and-widgets'),
			'group'			=> "Design",
		),		
   )
));	