<!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>
	
	
	<link rel="preconnect" href="https://fonts.googleapis.com">
	<link rel="preconnect" href="https://fonts.gstatic.com" crossorigin>
	<link href="https://fonts.googleapis.com/css2?family=Poppins:ital,wght@0,100;0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,100;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900&display=swap" rel="stylesheet">

	<!-- Basic Page Needs
  ================================================== -->
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta name="google-site-verification" content="NMFaYMMGVVIP7o36jAttrQomRgkHZOeBFf_AJsI-j4c" />	
	
	<!-- Mobile Specific Metas
	================================================== -->
	<?php if(ot_get_option('responsive_design','on')=='on'){ ?>
		<meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1">
	<?php }else { ?>
		<meta name="viewport" content="width=1200" />
	<?php } ?>
	
	
	<?php
	// If WP4.3+ and no site_icon is set - show custom
	if ( ( function_exists( 'has_site_icon' ) && !has_site_icon() ) ) { ?>
		<link rel="icon" type="image/x-icon" href="<?php echo esc_url(ot_get_option('favicon_uploaded', get_template_directory_uri().'/images/favicon.png'));?>">
	<?php }
	// If before WP4.3 - show custom
	if ( ! ( function_exists( 'wp_site_icon' ) ) ) { ?>
		<link rel="icon" type="image/x-icon" href="<?php echo esc_url(ot_get_option('favicon_uploaded', get_template_directory_uri().'/images/favicon.png'));?>">		
	<?php } ?>
	
	<?php wp_head(); ?>	
	
<style>
h1, h2, h3, h4, h5, h6, p, a, li, span, body {
	font-family: "Poppins", sans-serif;
}
.About-home {
    padding-top: 5rem;
    padding-bottom: 5rem;
}	
.About-home h2 span {
    border-top: 2px solid #0068C1;
}
.btn-home.button {
    text-transform: capitalize;
    padding: 10px 22px;
	display: table;
    margin: 0 auto;
}
	
	
	
	
</style>
</head>

<body <?php body_class(); ?>>

	<?php 
		do_action( 'boc_after_body_opening_tag' );
		
		$page_heading_style 		= ot_get_option('page_heading_style','page_title_bgr bgr_style1');
		$sticky_header 				= boc_is_header_sticky();
		$header_full_width			= boc_is_header_full_width();
		$subheader 					= boc_get_is_subheader_on();
		$hide_subheader_on_scroll 	= ot_get_option('hide_subheader_on_scroll','on') == 'on';
		$is_transparent_header 		= boc_is_transparent_header();
		$has_page_preloader			= boc_has_page_preloader();

		if($is_transparent_header){
			$transparent_logo_effect = boc_get_transparent_logo_effect();
		}
		$responsive_option 	= boc_responsive_option();
		$wrapper_style 		= boc_page_wrapper_style();
		$wrapper_width 		= ot_get_option('wrapper_width','');
		
		// Check if Header is disabled
		$header_is_off = false;
		if(isset($post->ID)){
			// Check Page Settings also
			$header_is_off = get_post_meta($post->ID, 'boc_header_is_off', true)=='on' ? true : false;
		}
		
		// Side Nav
		$side_nav = boc_get_side_nav();
		if($side_nav) {
			echo wp_kses_post($side_nav);
		}
	?>


	<?php if($has_page_preloader){	// Preloader 	?>	
		<div id="boc_page_preloader">
			 <svg class="spinner" viewBox="0 0 50 50">
              <circle class="path" cx="25" cy="25" r="20" fill="none" stroke-width="4"></circle>
            </svg>
		</div>
	<?php }	?>

	
	
  <!-- Page Wrapper::START -->
  <div id="wrapper" class="<?php echo esc_attr( $wrapper_style.' '.$wrapper_width.' '.$page_heading_style.' '.$responsive_option.' wrapper_'.boc_get_navigation_style());?> ">

	<?php if(!$header_is_off) { ?>
	<!-- Header::START -->
	<header id= "header"
		class= "<?php echo (bool)$subheader ? 'has_subheader' : 'no_subheader';?>
		<?php echo (bool)$header_full_width ? 'header_full_width' : '';?>
		<?php echo (bool)$is_transparent_header ? 'transparent_header' : '';?>
		<?php echo (bool)$sticky_header ? 'sticky_header' : '';?>
		<?php echo esc_attr(($sticky_header && $hide_subheader_on_scroll) ? 'hide_subheader_on_scroll' : '');?>
		<?php echo ((boc_get_navigation_style()=="menu_regular_style menu_toplogo") && ot_get_option("nav_hide_logo_on_scroll")) ? 'hide_top_logo' : '';?>">

		<?php if($subheader){ ?>
		<!-- SubHeader -->
		<div class="full_header">
			<div id="subheader" class="container">	
				<div class="section">

					<?php do_action( 'boc_after_subheader_start' );?>
				
					<?php $header_contacts_position_is_left = ot_get_option('header_contacts_position_is_left'); ?>		
					<div class="header_contacts <?php echo (!$header_contacts_position_is_left? "right": '');?>">
						<?php if($header_email = ot_get_option('header_email')){?>
							<div class="header_contact_item"><span class="fa fa-envelope"></span> <?php echo antispambot(wp_kses_post($header_email));?></div>
						<?php }  ?>	
						<?php if($header_address = ot_get_option('header_address')){?>
							<div class="header_contact_item"><span class="boc_i-location"></span> <?php echo wp_kses_post($header_address);?></div>
						<?php }  ?>
						<?php if($header_hours = ot_get_option('header_hours')){?>
							<div class="header_contact_item"><span class="fa fa-clock-o"></span> <?php echo wp_kses_post($header_hours);?></div>
						<?php }  ?>
						<?php if($header_phone = ot_get_option('header_phone')){?>
							<div class="header_contact_item"><span class="fa fa-phone"></span> <?php echo wp_kses_post($header_phone);?></div>
						<?php }  ?>
					</div>

					<?php if(is_array($header_icons = ot_get_option('header_icons'))){

							echo "<div class='header_soc_icon_holder ".(!$header_contacts_position_is_left ? "left": '')."'>";
							
							foreach($header_icons as $header_icon){
								echo "<a target='_blank' 
										href='". ( $header_icon['icons_service']!='rss' ? $header_icon['icons_url'] : get_bloginfo('rss2_url') )."' 
										class='header_soc_icon'										
										title='". esc_attr($header_icon['title']) ."'>
										<span class='icon ". esc_attr($header_icon['icons_service']) ."'></span></a>";			
							}
							
                   echo  "<a href='#' class='header_search_icon fa fa-search'></a> ";
                
							echo "</div>";	
						  }
					?>
					
					<?php if ( is_active_sidebar( 'alea_subheader_widget_area' )) { ?>
					<!-- Subheader Widget::START -->
					<div class="boc_subheader_widget"><?php dynamic_sidebar( 'alea_subheader_widget_area' ); ?></div>
					<!-- Subheader Widget::END -->
					<?php }?>					

					
					<?php 
					// Subheader Menu if set
					if ( has_nav_menu( 'subheader_navigation' ) ) {
						wp_nav_menu( array(
							'theme_location'	=> 'subheader_navigation',
							'container_id'	=> 'subheader_menu', 
							'items_wrap' 		=> '<ul>%3$s</ul>',
						));
					}
					?>


				</div>
			</div>
		</div>
		<?php }  ?>
		
		<div class="main_header">
		
			<div class="container">
			
				<div class="section">
			
					<?php
						do_action( 'boc_before_logo' );
					
						// Logo
						$logo_data = wp_get_attachment_image_src(ot_get_option('logo_upload'), 'full');
						$logo = ($logo_data ? $logo_data[0] : get_template_directory_uri().'/images/logo.png');
						$logo_max_width = ($logo_data ? $logo_data[1] : 117);
						
						// Transparent Logo
						if($is_transparent_header){
							$logo_transparent_data = wp_get_attachment_image_src(ot_get_option('logo_transparent_upload'), 'full');
							$logo_transparent = ($logo_transparent_data ? $logo_transparent_data[0] : get_template_directory_uri().'/images/logo_transp.png');
							$logo_transparent_max_width = ($logo_transparent_data ? $logo_transparent_data[1] : 117);
						}
					?>

					
					
					<div id="logo" style="width: <?php echo (int)$logo_max_width;?>px;">
						<div class='logo_img <?php echo (bool)($is_transparent_header && $logo_transparent) ? "transparent_logo_".esc_attr($transparent_logo_effect) : "";?>'>
							<a href="<?php echo esc_url(home_url('/')); ?>" title="<?php echo esc_attr(get_bloginfo('name', 'display')); ?>" rel="home">
								<img src="<?php echo esc_url($logo); ?>" alt="<?php bloginfo('name'); ?>" style="max-width: <?php echo (int)$logo_max_width;?>px;"/>
								<?php if($is_transparent_header && $logo_transparent) { ?>
									<span id="transparent_logo"><img src="<?php echo esc_url($logo_transparent); ?>" alt="<?php bloginfo('name'); ?>" style="max-width: <?php echo (int)$logo_transparent_max_width;?>px;"/></span>
								<?php } ?>
							</a>
						</div>
					</div>

				<?php
					do_action( 'boc_after_logo' );
				?>

				<?php 
				// Include Header Navigation Part
				if(boc_get_navigation_style()=="menu_regular_style"){
					get_template_part('templates/menu/menu_regular_style');
				}elseif (boc_get_navigation_style()=="menu_regular_style menu_midlogo"){
					get_template_part('templates/menu/menu_regular_style');
				}elseif (boc_get_navigation_style()=="menu_regular_style menu_toplogo"){
					get_template_part('templates/menu/menu_regular_style');
				}elseif (boc_get_navigation_style()=="menu_stripe_style"){
					get_template_part('templates/menu/menu_stripe_style');
				}elseif (boc_get_navigation_style()=="menu_angular_style"){
					get_template_part('templates/menu/menu_angular_style');
				}elseif (boc_get_navigation_style()=="menu_solid_style"){
					get_template_part('templates/menu/menu_solid_style');
				} ?>
				

			</div>
		</div>


		<?php
			// Mobile header
			$mobile_logo_data = wp_get_attachment_image_src(ot_get_option('mobile_logo_upload'));
			$mobile_logo = ($mobile_logo_data ? $mobile_logo_data[0] : $logo);
			$mobile_logo_max_width = ($mobile_logo_data ? $mobile_logo_data[1] : $logo_max_width);
			
			$mobile_header_always_sticky = (ot_get_option('mobile_header_always_sticky','off') == 'on') ? 'mobile_header_always_sticky' : '';
		?>
		
		<div id="mobile_header" class="<?php echo $mobile_header_always_sticky; ?>">
		
			<div class="mobile_header_holder">
				
				<div id="mobile_logo">
					<a href="<?php echo esc_url(home_url('/')); ?>" title="<?php echo esc_attr(get_bloginfo('name', 'display')); ?>">
						<img src="<?php echo esc_url($mobile_logo); ?>" alt="<?php bloginfo('name'); ?>" style="max-width: <?php echo (int)$mobile_logo_max_width;?>px;"/>
					</a>
				</div>
				
				<!-- Mobile Menu Toggler -->
				<div id="mobile_menu_toggler">
					<div id="m_nav_menu" class="m_nav">
						<div class="m_nav_ham button_closed" id="m_ham_1"></div>
						<div class="m_nav_ham button_closed" id="m_ham_2"></div>
						<div class="m_nav_ham button_closed" id="m_ham_3"></div>
					</div>
				</div>			
			
				<div id="mobile_menu">
					<div class="mobile_scroll">
					<?php 
						if ( has_nav_menu( 'main_navigation' ) ) {
							wp_nav_menu( array(
								'theme_location'=> 'main_navigation',
								'container' 	=> '',
								'menu_class' 	=> '', 
								'walker' 		=> new boc_Menu_Walker,
								'items_wrap' => '<ul class="mobile_menu_ul">%3$s</ul>',
							));
						}
						
						// Show Search
						$mobile_show_search_option = boc_mobile_show_search_in_header();				
						if($mobile_show_search_option=='on') {
							$product_search_hidden_field = '';
							if(ot_get_option('woocommerce_header_product_search','off')=='on'){
								$product_search_hidden_field = "<input type='hidden' name='post_type' id='post_type' value='product'/>";
							}
							echo '<form method="get" action="'.esc_url( home_url( '/' ) ).'" role="search" class="mobile_search_form"><input type="search" name="s" autocomplete="off" placeholder="'.esc_attr__( 'Search...', 'alea' ).'" />'.$product_search_hidden_field.'</form>';
						}
						?>
						
						<?php if(ot_get_option('subheader_contacts_show_in_mobile','on')=='on'){ ?>
						<div class="header_contacts_mobile">
							<?php if($header_email = ot_get_option('header_email')){?>
								<div class="header_contact_item_mobile"><span class="fa fa-envelope"></span> <?php echo antispambot(wp_kses_post($header_email));?></div>
							<?php }  ?>	
							<?php if($header_address = ot_get_option('header_address')){?>
								<div class="header_contact_item_mobile"><span class="boc_i-location"></span> <?php echo wp_kses_post($header_address);?></div>
							<?php }  ?>
							<?php if($header_hours = ot_get_option('header_hours')){?>
								<div class="header_contact_item_mobile"><span class="fa fa-clock-o"></span> <?php echo wp_kses_post($header_hours);?></div>
							<?php }  ?>
							<?php if($header_phone = ot_get_option('header_phone')){?>
								<div class="header_contact_item_mobile"><span class="fa fa-phone"></span> <?php echo wp_kses_post($header_phone);?></div>
							<?php }  ?>
						</div>
						<?php }  ?>

						<?php if((ot_get_option('subheader_social_icons_show_in_mobile','on')=='on')&&(is_array($header_icons = ot_get_option('header_icons')))){

								echo "<div class='header_soc_icon_holder_mobile'>";
								
								foreach($header_icons as $header_icon){
									echo "<a target='_blank' 
											href='". ( $header_icon['icons_service']!='rss' ? $header_icon['icons_url'] : get_bloginfo('rss2_url') )."' 
											class='header_soc_icon'										
											title='". esc_attr($header_icon['title']) ."'>
											<span class='icon ". esc_attr($header_icon['icons_service']) ."'></span></a>";			
								}
								
								echo "</div>";	
							  }
						?>
						
						<?php do_action( 'boc_before_mobile_menu_popup_closing_tag' ); ?>

					</div>
				</div>
				
				<?php if ( is_active_sidebar( 'alea_side_widget_area' ) ) : ?>
					<div id="mobile_boc_menu_icon">
						<div class="boc_menu_icon_ham button_closed line_1" id="mobile_boc_menu_icon_ham_1"></div>
						<div class="boc_menu_icon_ham button_closed line_2" id="mobile_boc_menu_icon_ham_2"></div>
						<div class="boc_menu_icon_ham button_closed line_3" id="mobile_boc_menu_icon_ham_3"></div>
					</div>
				<?php endif; ?>
				
				<?php
				// Mobile Cart in Header
				if (boc_cart_in_header()) {
					boc_render_cart_in_header();
				}
				?>

			</div>
		</div>
	
	</header>
	<!-- Header::END -->
	<?php } ?>
		
	
	
	<!-- Page content::START -->
	<div class="content_body">
	
	<?php do_action( 'boc_after_content_opening_tag' ); ?>
	
	<?php boc_page_header();