<?php

class OptionTreeImporter {

    /**
     * Import OptionTree data from a file, generated by the OptionTree plugin.
     *
     * @param string OptionTree exported raw data.
     */
    public static function import($import_data) {

        $options = unserialize(ot_decode($import_data));

        /* get settings array */
        $settings = get_option(ot_settings_id());

        /* has options */
        if (is_array($options)) {

            /* validate options */
            if (is_array($settings)) {

                foreach ($settings['settings'] as $setting) {

                    if (isset($options[$setting['id']])) {

                        $content = ot_stripslashes($options[$setting['id']]);
                        $options[$setting['id']] = ot_validate_setting($content, $setting['type'], $setting['id']);
                    }
                }
            }

            /* update the option tree array */
            update_option(ot_options_id(), $options);
        }
    }
}


// --------------------------------------
// Initialize OneClick Demo Import plugin
// --------------------------------------
function boc_ocdi_import_files() {

    $dirDemoData = realpath(trailingslashit(get_template_directory())) . DIRECTORY_SEPARATOR . 'demodata' . DIRECTORY_SEPARATOR;

    $importXML = glob($dirDemoData . '*.xml');
    $importWidget = glob($dirDemoData . 'widgets' . DIRECTORY_SEPARATOR . '*.wie');
    //$importCustomizer = glob($dirDemoData . 'Customizer' . DIRECTORY_SEPARATOR . '*.*');
    $importOptionTree = glob($dirDemoData . 'optiontree' . DIRECTORY_SEPARATOR . '*.txt');
    //$importRedux = glob($dirDemoData . 'Redux' . DIRECTORY_SEPARATOR . '*.*');

    $settings = array();

    if (!empty($importXML)) {
        $settings['local_import_file'] = $importXML[0];
    }

    if (!empty($importOptionTree)) {
        $settings['local_import_ot_file'] = $importOptionTree[0];
    }
	
    if (!empty($importWidget)) {
        $settings['local_import_widget_file'] = $importWidget[0];
    }

    if (empty($settings)) {
        return array();
    }

    $settings['import_file_name'] = esc_html__('Alea Demo Data Import', 'alea');
    $settings['import_notice'] = esc_html__('After you import Alea demo, you can setup the Revolution sliders separately. ', 'alea').' <a target="_blank" href="http://blueowlcreative.com/docs/alea/#main_tabs37">Importing Revolution Slider Demo sliders</a>';
	
	// Enable SVGs if importing
	if(!empty($_POST['action']) && (sanitize_text_field($_POST['action']) == 'ocdi_import_demo_data')){
		add_filter('upload_mimes', 'upload_svg_mime_type');
	}
    return array($settings);
}
add_filter('pt-ocdi/import_files', 'boc_ocdi_import_files');


// Enable SVG upload for import only
function upload_svg_mime_type($mimes) {
  $mimes['svg'] = 'image/svg+xml';
  return $mimes;
}
// Remove branding
add_filter( 'pt-ocdi/disable_pt_branding', '__return_true' );


// -----------------------------
// Handle OptionTree import type
// -----------------------------
function boc_after_content_import_execution($selected_import_files, $import_files, $selected_index) {

    $downloader = new OCDI\Downloader();

    if (!empty($import_files[$selected_index]['import_ot_file'])) {
        $file_path = $downloader->download_file($import_files[$selected_index]['import_ot_file'], 'demo-ot-import-file-' . $selected_index . '-' . date('Y-m-d__H-i-s') . '.txt');
        $file_raw = OCDI\Helpers::data_from_file($file_path);
        OptionTreeImporter::import($file_raw);
    } else if (!empty($import_files[$selected_index]['local_import_ot_file'])) {
        $file_path = $import_files[$selected_index]['local_import_ot_file'];
        $file_raw = OCDI\Helpers::data_from_file($file_path);
        OptionTreeImporter::import($file_raw);
    }

    $ocdi = OCDI\OneClickDemoImport::get_instance();
    $log_path = $ocdi->get_log_file_path();

    OCDI\Helpers::append_to_file('OptionTree file loaded.', $log_path);
}
add_action('pt-ocdi/after_content_import_execution', 'boc_after_content_import_execution', 3, 99);


// -----------------------------------
// After import
// -----------------------------------
function boc_ocdi_after_import($selected_import) {

	// Set main menu to Main Nav slot
	$main_menu = get_term_by( 'name', 'Main Menu', 'nav_menu' );
	if ( isset( $main_menu->term_id )){
			set_theme_mod( 'nav_menu_locations', array(
			'main_navigation' => $main_menu->term_id,
		));
	}
	// Set Home page
	$homepage = get_page_by_title( 'Agency Green' );
	if($homepage)	{
		update_option( 'page_on_front', $homepage->ID );
		update_option( 'show_on_front', 'page' );
	}
	// Set Blog page
	$blog = get_page_by_title( 'Blog' );
	if($blog)	{
		update_option( 'page_for_posts', $blog->ID );
	}
	
	// Set portfolio Formats
	update_post_meta(404, 'boc_portfolio_template_select_option', 'vertical_gallery');
	set_post_format(404, 'gallery');
	update_post_meta(1421, 'boc_portfolio_template_select_option', 'full');
	set_post_format(1421, 'gallery');
	update_post_meta(411, 'boc_portfolio_template_select_option', 'full');
	set_post_format(411, 'video');
	set_post_format(431, 'gallery');
	
	// Set Video Fixer to ON for Parallax & Video for VC plugin
	update_option('ultimate_video_fixer', 'enable');
	
}
add_action('pt-ocdi/after_import', 'boc_ocdi_after_import');
