<?php 
/**
 * Initialize the meta boxes. 
 */
add_action( 'admin_init', 'boc_meta_boxes' );

if( ! function_exists( 'boc_meta_boxes' ) ) {
	function boc_meta_boxes() {

	  /**
	   * Create a custom meta boxes array that we pass to 
	   * the OptionTree Meta Box API Class.
	   */

		$sidebars = ot_get_option('boc_sidebars');
		$sidebars_array = array();
		$sidebars_array[0] = array (
			'label' => "Alea Default Sidebar",
			'value' => 'Alea Default Sidebar'
		);

		$sidebars_k = 1;
		if(!empty($sidebars)){
			foreach($sidebars as $sidebar){
				$sidebars_array[$sidebars_k++] = array(
					'label' => $sidebar['title'],
					'value' => $sidebar['id']
				);
			}
		}
	   
	  $boc_sidebar_meta = array(
		'id'        => 'boc_sidebar_settings',
		'title'     => 'Alea Sidebar Settings',
		'desc'      => 'Overwrite the Default Sidebar Options set in your <a href="'.esc_url(admin_url("?page=ot-theme-options#section_general")).'">Alea Options</a>',
		'pages'     => array( 'post','page'),
		'context'   => 'side',
		'priority'  => 'default',
		'fields'    => array(
		  array(
			'id'          => 'boc_meta_sidebar_layout',
			'label'       => 'Sidebar Layout',
			'std'         => 'default',
			'type'        => 'select',
			'choices'     => array (
								array(
									'label' => "Default (Set in Theme Options)",
									'value' => 'default'
								),	
								array(
									'label' => "No Sidebar",
									'value' => 'full-width'
								),		
								array(
									'label' => "Left Sidebar",
									'value' => 'left-sidebar'
								),	
								array(
									'label' => "Right Sidebar",
									'value' => 'right-sidebar'
								)
							)
		  ),
		  array(
			'id'          => 'boc_sidebar_set',
			'label'       => 'Sidebar',
			'type'        => 'select',
			'choices'     => $sidebars_array,
			'condition'	  => "boc_meta_sidebar_layout:not(full-width)",
			),     
		  )
		);
		ot_register_meta_box( $boc_sidebar_meta );
		


		
		// Gallery post type
		$boc_post_gallery_options = 
		array(
		'id'        => 'boc_post_gallery_options',
		'title'     => 'Gallery',
		'desc'      => '',
		'pages'     => array( 'post','portfolio' ),
		'context'   => 'normal',
		'priority'  => 'high',
		'fields'    => array(

		  array(
			'id'          => 'gallery',
			'label'       => 'Pick your Gallery Images',
			'type'        => 'gallery',
			)
		  )  
		);
		ot_register_meta_box( $boc_post_gallery_options );
		
		// Video post type
		$boc_post_video_options = array(
			'id'        => 'boc_post_video_options',
			'title'     => 'Video Post Options',
			'desc'      => '',
			'pages'     => array( 'post','portfolio' ),
			'context'   => 'normal',
			'priority'  => 'high',
			'fields'    => array(
				array(
					'id'          => 'video_embed_code',
					'label'       => 'Paste your Video Embed Code',
					'type'        => 'text',
				)
			)
		);
		ot_register_meta_box( $boc_post_video_options );
		
		
		// Posts Template picker
		$boc_posts_template_select = array(
			'id'        => 'boc_posts_template_select',
			'context'   => 'side',
			'priority'  => 'default',
			'title'		=> 'Post Template',
			'pages'     => array('post'),
			'fields'    => array(
				 array(
					'id'        => 'boc_posts_template_select_option',
					'type'      => 'select',
					'std'       => 'regular',
					'choices' 	=> array(
						array('label' => 'Default (from Theme Options)'		, 'value' => 'default'),
						array('label' => 'Featured Image above content'		, 'value' => 'regular'),
						array('label' => 'Full Width Featured Image BGR'	, 'value' => 'full'),
						array('label' => 'Side Meta'						, 'value' => 'side'),
					),
				)
			),
		);
		ot_register_meta_box( $boc_posts_template_select );
		
		
		// Portfolio Template picker
		$boc_portfolio_template_select = array(
			'id'        => 'boc_portfolio_template_select',
			'context'   => 'side',
			'priority'  => 'default',
			'title'		=> 'Portfolio Template',
			'pages'     => array('portfolio'),
			'fields'    => array(
				 array(
					'id'        => 'boc_portfolio_template_select_option',
					'type'      => 'select',
					'std'       => 'regular',
					'choices' 	=> array(
						array('label' => 'Side Media (Default)'	, 'value' => 'default'),
						array('label' => 'Wide Media'			, 'value' => 'full'),
						array('label' => 'Side Vertical Gallery', 'value' => 'vertical_gallery'),
						array('label' => 'Custom (Empty)'		, 'value' => 'empty'),
					),
				)
			),
		);
		ot_register_meta_box( $boc_portfolio_template_select );
		
		
		
		// Portfolio Metro Grid Size
		$boc_portfolio_metro_size = array(
				'id'        => 'boc_portfolio_metro_size',
				'context'   => 'side',
				'title'		=> 'Metro Grid Size',
				'pages'     => array('portfolio'),
				'priority'  => 'default',			
				'fields'    => array(
					 array(
						'id'        => 'boc_portfolio_metro_size_options',
						'type'      => 'select',
						'std'       => 'boc_medium',
						'choices' 	=> array(
							array('label' => 'Regular'		, 'value' 	=> 'boc_medium'),
							array('label' => 'Wide'			, 'value'	=> 'boc_wide'),
							array('label' => 'Tall'			, 'value'	=> 'boc_tall'),
							array('label' => 'Wide & Tall'	, 'value'	=> 'boc_widetall'),
						),
					)
				),
				'desc'		=> 'Size Proportions to use when item shows in metro grid format',
		);
		ot_register_meta_box( $boc_portfolio_metro_size );
		

		
		// Page Settings
		
		// Get Menus to populate options for "Side Nav"
		$boc_registered_menus = boc_get_available_menus();
		
	  
		$boc_page_settings = array(
		'id'        => 'boc_page_settings',
		'title'     => 'Alea Page Settings',
		'pages'     => array( 'post','page', 'product', 'portfolio'),
		'context'   => 'normal',
		'priority'  => 'high',
		'fields'    => array(
			array(
				'id'          => 'boc_page_wrapper_style',
				'label'       => 'Page Wrapper Style',
				'desc'        => 'Overwrite the Default Wrapper Style (set in Theme Options) for this page.',
				'std'         => 'default',
				'type'        => 'select',
				'class'       => '',
				'choices'     => array (
									array(
										'label' => "Default (Set in Theme Options)",
										'value' => 'default'
									),
									array(
										'label' => "Boxed",
										'value' => 'boxed_wrapper'
									),
									array(
										'label' => "Full Width",
										'value' => 'full_width_wrapper'
									),
								)
			),
			array(
				'id'          => 'boc_page_bgr',
				'label'       => 'Set explicit Page background',
				'type'        => 'background',
				'desc'		=> 'Type "cover" for background-size if you want the background image to stretch full width.',
				'condition'	  => "boc_page_wrapper_style:is(boxed_wrapper)",
			),		
			array(
				'id'          => 'boc_page_heading_set',
				'label'       => 'Show Page Heading',
				'desc'        => 'This is the area that contains the Page Title and Breadcrumbs, right below the header',
				'std'         => apply_filters('boc_override_default_page_settings_page_heading', 'on'),
				'type'        => 'on_off',
			),
			array(
				'id'          => 'boc_page_breadcrumbs',
				'label'       => 'Show Breadcrumbs',
				'desc'        => 'The area in your Page heading that looks like: Home -> Page Name',
				'std'         => 'on',
				'type'        => 'on_off',
				'class'       => 'page_heading_sub1',
				'condition'	  => "boc_page_heading_set:is(on)",
			),
			array(
				'id'          => 'boc_page_tall_heading',
				'label'       => 'Tall Heading Area',
				'desc'        => 'Add a bigger top/bottom padding to the Heading section',
				'std'         => 'off',
				'type'        => 'on_off',
				'class'       => 'page_heading_sub2',
				'condition'	  => "boc_page_heading_set:is(on)",
			),
			array(
				'id'          => 'boc_page_heading_white_text_meta',
				'label'       => 'White Text in Page Heading',
				'desc'        => 'Force white color for Page Heading area text (if using a dark BGR)',
				'std'         => 'off',
				'type'        => 'on_off',
				'class'       => 'page_heading_sub2',
				'condition'	  => "boc_page_heading_set:is(on)",
			),		
			array(
				'id'          => 'boc_page_heading_bgr_meta',
				'label'       => 'Overwrite default Page Heading background',
				'type'        => 'background',
				'desc'		=> 'Set this to overwrite the default setting from Theme Options for this specific page. Type "cover" for background-size if you want the background image to stretch full width.',
				'class'       => 'sub_section_meta',
				'condition'	  => "boc_page_heading_set:is(on)",
			),
			array(
				'id'          => 'boc_content_top_margin',
				'label'       => 'Page Content Top Margin',
				'desc'        => 'Page content will be slightly pushed down from your header/page heading area if On',
				'std'         => apply_filters('boc_override_default_page_settings_content_top_margin', 'on'),
				'class'       => 'clear_section_meta',
				'type'        => 'on_off',
			),
			array(
				'id'          => 'boc_transparent_header_set',
				'label'       => 'Activate Transparent Header',
				'std'         => apply_filters('boc_override_default_page_settings_transparent_header', 'off'),
				'type'        => 'on_off',
				'desc'        => 'Further Manage your Transparent Menu Settings in your <a href="'.admin_url("?page=ot-theme-options#tab_transparent_header").'">Alea Options</a>',	
			),
			array(
				'id'          => 'has_page_preloader_set',
				'label'       => 'Activate Preloader Animation for this Page',
				'std'         => 'off',
				'type'        => 'on_off',
				'desc'        => 'If "Preloader Animation" is globally set to OFF in your Theme Options (General) you can overwrite it here for this page only',	
			),
			array(
				'id'          => 'boc_page_side_nav',
				'label'       => 'Activate a Dotted-Style Side Navigation for this Page',
				'desc'        => 'Select a dotted Side Nav for this page. Make sure you have created a Menu and it matches the section IDs in your page. Only available for custom pages.',
				'std'         => 'default',
				'type'        => 'select',
				'class'       => '',
				'choices'     => $boc_registered_menus
			),		
			array(
				'id'          => 'boc_header_is_off',
				'label'       => 'Disable Header for this Page',
				'std'         => 'off',
				'type'        => 'on_off'
			),
			array(
				'id'          => 'boc_footer_is_off',
				'label'       => 'Disable Footer for this Page',
				'std'         => 'off',
				'type'        => 'on_off'
			),		
		)
		);

		ot_register_meta_box( $boc_page_settings );	
		
	}
}


/**
 * Handle Gallery Metabox on Post editing page 
 */

add_action( 'admin_print_scripts', 'boc_display_metaboxes', 1000 );

if( ! function_exists( 'boc_display_metaboxes' ) ) {
	function boc_display_metaboxes() {
		global $pagenow;
		if( 'post.php' != $pagenow && 'post-new.php' != $pagenow ) return; // Not editing a page, bye!
		if ((get_post_type() == "post") || (get_post_type() == "portfolio")) { 
			$js =
			"jQuery( function($) {
				$ = jQuery;
				function displayBOCMetaboxes() {
					$('#boc_post_gallery_options, #boc_post_video_options').hide();
					
					var selectedPostFormat = $('input[name=\"post_format\"]:checked').val();			
					
					if ( selectedPostFormat ) {
						if ( selectedPostFormat == 'gallery' ) {
							$('#boc_post_gallery_options').fadeIn();
						}
						if ( selectedPostFormat == 'video' ) {
							$('#boc_post_video_options').fadeIn();
						}
					}		
				}
				$(function() {
					displayBOCMetaboxes();
					$('input[name=\"post_format\"]').change(function() {
						displayBOCMetaboxes();
					});
				});
			 });";
			
			wp_register_script( 'boc_admin_inline_script', false);
			wp_enqueue_script( 'boc_admin_inline_script');
			wp_add_inline_script( 'boc_admin_inline_script', $js );
			
		} // End if post	
	}
}
